pub struct Pict<'a> {
pub shape: Option<Shape<'a>>,
pub rect: Option<Rect<'a>>,
}Expand description
VML Object (Legacy Image)
Fields
shape: Option<Shape<'a>>Specifies the content of the VML object For now, we mainly care about v:shape -> v:imagedata accessing images But parsing full VML is complex. We will try to capture raw children or specific known children. hard_xml doesn’t support “any child”, so we define common VML shapes.
rect: Option<Rect<'a>>Trait Implementations
Sourceimpl<'a> From<Pict<'a>> for RunContent<'a>
impl<'a> From<Pict<'a>> for RunContent<'a>
Sourcefn from(original: Pict<'a>) -> RunContent<'a>
fn from(original: Pict<'a>) -> RunContent<'a>
Converts to this type from the input type.